#!/usr/local/bin/python
#
# zapconv59.py
# Copyright 2000 Adam Feuer
# Adam Feuer <adamf@pobox.com>
#
# This file is part of adzapper.
#
# adzapper is free software; you can redistribute it and/or modify
# it under the terms of the Zope Public License 1.0 as published by
# Digital Creations.
#
# adzapper is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# Zope Public License for more details.
#
# You should have received a copy of the Zope Public License 1.0
# along with adzapper; see the file COPYING.
#
#  "This product includes software developed by Digital Creations
#  for use in the Z Object Publishing Environment
#  (http://www.zope.org/)."
#
#
# zapconv.py converts zaplets in version 0.5 format to xml format
#		
#
"""Usage:

python zapconv59.py [-h] [-v] [-d debuglevel] [-o output_directory] [-i input_dir] 

Converts all the zaplets in the output_directory from format v0.5 to format v0.9 (XML-based).

If no output directory is specified, print XML zaplets to STDOUT.

Options:

-h                     print this text
-v                     print version information
-d [debuglevel]        print debugging information; debuglevel must be an integer,
                            higher numbers == more information
-o [output_dir]        output directory to save XML zaplets in
-i [input_dir]         input directory to read zaplets from; defaults to 'zaplets'


"""

RCS_ID =  '$Id: zapconv59.py,v 1.1 2000/08/11 06:37:00 adamf Exp $'


# global variables
MAJOR_VERSION = 0
MINOR_VERSION = 1
SUB_VERSION   = 1     # ;-)  

# zaplet config stuff
ZAPLET_DIR = 'zaplets'

# standard modules
import string
import getopt
import os
import sys

import debug


if __name__ == '__main__':
    # adzapper and zaplet modules
    import zapreader

    # debugging defaults to off
    debug.debuglevel = 0

    # set the defaults for zaplet directory and config file
    input_dir = ZAPLET_DIR
    output_dir = None

    program_name = sys.argv[0]
    args = sys.argv[1:]
    debug.debug (1,("args: ",  args))

    try:
        optlist, arglist = getopt.getopt(args, 'hvd:o:i:')
    except getopt.error, error_message:
        print "error message: %s" % error_message
        print
        print __doc__ % vars()
        raise SystemExit

    debug.debug(1,('args: ' , args))
    debug.debug(1,('optlist' , optlist))
    debug.debug(1,('arglist: ' , arglist))

    if arglist == []:
        pass
    else:
        debug.debug(1, 'port: %s ' % arglist[0])
        file = arglist[0]

    if '-h' in args:
        print __doc__ % vars()
        raise SystemExit

    if '-v' in args:
        VERSION_STRING = '%d.%d.%d' % (MAJOR_VERSION,MINOR_VERSION,SUB_VERSION)
        print '%s version: %s' % (program_name,VERSION_STRING)
        raise SystemExit

    if '-d' in args:
        for list_item in optlist:
            if list_item[0] == '-d':
                debug.debuglevel = string.atoi(list_item[1])

    if '-i' in args:
        for list_item in optlist:
            if list_item[0] == '-i':
                input_dir = list_item[1]
                
    if '-o' in args:
        for list_item in optlist:
            if list_item[0] == '-o':
                output_dir = list_item[1]
                
    debug.debug(1,'Debugging output is turned on at level %d' % debug.debuglevel)

    debug.debug(1,"zaplet directory is: %s" % input_dir)
    debug.debug(1,"output directory is: %s" % output_dir)

    # initialize zaplet engine
    ze = zapreader.zaplet_converter_engine(input_dir)

    if output_dir != None:
        ze.write_xml_all_zaplets(output_dir)
    else:
        ze.print_xml_all_zaplets()

